import { Component, OnInit, Input, Output, EventEmitter } from '@angular/core';
import { Observable } from 'rxjs';

import * as AppStore from '@app/store';
import { select, Store } from '@ngrx/store';

import { MainMenu } from '@app/types';
import { tap } from 'rxjs/operators';

@Component({
  selector: 'app-layout-messenger-main-contents',
  templateUrl: './main-contents.component.html',
  styleUrls: ['./main-contents.component.scss']
})
export class MainContentsComponent implements OnInit {
  @Input()
  selectedChat: Observable<string | null>;

  @Output()
  openProfile = new EventEmitter<{
    userSeq: number;
  }>();

  @Output()
  sendCall = new EventEmitter<string>();

  @Output()
  closeRightDrawer = new EventEmitter();

  @Output()
  createConference = new EventEmitter<number[]>();

  MainMenu = MainMenu;
  gnbMenuIndex$: Observable<string>;

  constructor(private store: Store<any>) {}

  ngOnInit() {
    this.gnbMenuIndex$ = this.store.pipe(
      select(AppStore.MessengerSelector.SettingsSelector.gnbMenuIndex),
      tap(index => {
        if (index === MainMenu.Organization) {
          this.closeRightDrawer.emit();
        }
      })
    );
  }

  onClickOpenProfile(userSeq: number) {
    this.openProfile.emit({ userSeq });
  }
  onClickSendClickToCall(calleeNumber: string) {
    this.sendCall.emit(calleeNumber);
  }

  onCloseRightDrawer() {
    this.closeRightDrawer.emit();
  }

  onClickConferenceCreate(userSeqs: number[]) {
    this.createConference.emit(userSeqs);
  }
}
