import {
  Component,
  OnInit,
  Inject,
  OnDestroy,
  AfterViewInit,
  ElementRef
} from '@angular/core';
import { MatDialogRef, MAT_DIALOG_DATA } from '@angular/material/dialog';
import { NoticeList } from '@ucap-webmessenger/api-message';
import { UCAP_NATIVE_SERVICE, NativeService } from '@ucap-webmessenger/native';

export interface NoticeDetailDialogData {
  notice: NoticeList;
}

export interface NoticeDetailDialogResult {}

@Component({
  selector: 'app-notice-detail.dialog',
  templateUrl: './notice-detail.dialog.component.html',
  styleUrls: ['./notice-detail.dialog.component.scss']
})
export class NoticeDetailDialogComponent
  implements OnInit, OnDestroy, AfterViewInit {
  constructor(
    public dialogRef: MatDialogRef<
      NoticeDetailDialogData,
      NoticeDetailDialogResult
    >,
    @Inject(MAT_DIALOG_DATA) public data: NoticeDetailDialogData,
    private elementRef: ElementRef,
    @Inject(UCAP_NATIVE_SERVICE) private nativeService: NativeService
  ) {}

  ngOnInit() {}

  ngAfterViewInit(): void {
    if (
      !!this.elementRef.nativeElement &&
      !!this.elementRef.nativeElement.querySelector('a')
    ) {
      const elements = this.elementRef.nativeElement.querySelectorAll('a');
      elements.forEach(element => {
        element.addEventListener('click', this.onClickEvent.bind(this));
      });
    }
  }

  onClickEvent(event: MouseEvent) {
    this.nativeService.openDefaultBrowser(
      (event.target as HTMLAnchorElement).text
    );
  }

  ngOnDestroy(): void {}

  onClickConfirm(): void {
    this.dialogRef.close();
  }
}
